@@ -3,5 +3,5 @@ use askama::Template;
 #[derive(Template)]
 #[template(path = "index.html")]
 pub struct IndexTemplate<'a> {
-    pub api_address: &'a str,
+    pub api_url: &'a str,
 }
